# Atropos Manuscript

The manuscript was written using [Overleaf](https://www.overleaf.com). Upon publication 1) we will publicly share a read-only view of the manuscript on Overleaf, and 2) a copy of the final latex document will be copied into this folder.

To go from the generated figures/tables in 'workflow/results' to the final figures/tables in the manuscript, we tweaked the aesthetics of some figures using Illustrator and converted to PDF, and we reformatted some tables by hand-editing the latex; the data was left exactly as-is. 

We used Pandoc to generate the .DOCX file for submission to PeerJ. Some hand-editing of the .DOCX file was done to comply with the PeerJ submission requirements:

* Remove financial information from Acknowledgements
* Make equations editable
* Show line numbers

In the supplement, the MultiQC screenshot was generated manually based on one of the simulated FASTQ files (sim_01.1.fq).